==> mozc_1.1.773.102.orig.tar.gz: mozc-1.1.773.102/gui/about_dialog/about_dialog_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="about_dialog.ui" line="32"/>
        <source>About Mozc</source>
        <oldsource>About Google Japanese Inpt</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="59"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="85"/>
        <source>You are using the latest version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="105"/>
        <source>(0.0.0.0)</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="about_dialog.ui" line="145"/>
        <source>Copyright © 2011 Google Inc. All Rights Reserved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="160"/>
        <source>&lt;html&gt;&lt;body&gt;Mozc is made possible by &lt;a href=&quot;file://credits_en.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;open source software&lt;/span&gt;&lt;/a&gt;.&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="198"/>
        <source>&lt;html&gt;&lt;body&gt;Mozc &lt;a href=&quot;http://code.google.com/p/mozc/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;product information&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="239"/>
        <source>Mozc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="262"/>
        <source>0.0.0.0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mozc_1.4.1033.102.orig.tar.gz: mozc-1.4.1033.102/gui/about_dialog/about_dialog_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="about_dialog.ui" line="32"/>
        <source>About Mozc</source>
        <oldsource>About Google Japanese Inpt</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="59"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="about_dialog.ui" line="80"/>
        <source>Copyright © 2012 Google Inc. All Rights Reserved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="95"/>
        <source>&lt;html&gt;&lt;body&gt;Mozc is made possible by &lt;a href=&quot;file://credits_en.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;open source software&lt;/span&gt;&lt;/a&gt;.&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="133"/>
        <source>&lt;html&gt;&lt;body&gt;Mozc &lt;a href=&quot;http://code.google.com/p/mozc/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;product information&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="165"/>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="193"/>
        <source>Mozc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.ui" line="216"/>
        <source>0.0.0.0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::AboutDialog</name>
    <message>
        <location filename="about_dialog.cc" line="135"/>
        <source>New version is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="about_dialog.cc" line="146"/>
        <source>You are using the latest version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
